==> scipy-1.4.1.tar.gz: scipy-1.4.1/scipy/special/cephes/cephes_names.h <==
#ifndef CEPHES_NAMES_H
#define CEPHES_NAMES_H

#define airy cephes_airy
#define bdtrc cephes_bdtrc
#define bdtr cephes_bdtr
#define bdtri cephes_bdtri
#define besselpoly cephes_besselpoly
#define beta cephes_beta
#define lbeta cephes_lbeta
#define btdtr cephes_btdtr
#define cbrt cephes_cbrt
#define chdtrc cephes_chdtrc
#define chbevl cephes_chbevl
#define chdtr cephes_chdtr
#define chdtri cephes_chdtri
#define dawsn cephes_dawsn
#define ellie cephes_ellie
#define ellik cephes_ellik
#define ellpe cephes_ellpe
#define ellpj cephes_ellpj
#define ellpk cephes_ellpk
#define exp10 cephes_exp10
#define exp1m cephes_exp1m
#define exp2 cephes_exp2
#define expn cephes_expn
#define fdtrc cephes_fdtrc
#define fdtr cephes_fdtr
#define fdtri cephes_fdtri
#define fresnl cephes_fresnl
#define Gamma cephes_Gamma
#define lgam cephes_lgam
#define lgam_sgn cephes_lgam_sgn
#define gammasgn cephes_gammasgn
#define gdtr cephes_gdtr
#define gdtrc cephes_gdtrc
#define gdtri cephes_gdtri
#define hyp2f1 cephes_hyp2f1
#define hyperg cephes_hyperg
#define i0 cephes_i0
#define i0e cephes_i0e
#define i1 cephes_i1
#define i1e cephes_i1e
#define igamc cephes_igamc
#define igam cephes_igam
#define igami cephes_igami
#define incbet cephes_incbet
#define incbi cephes_incbi
#define iv cephes_iv
#define j0 cephes_j0
#define y0 cephes_y0
#define j1 cephes_j1
#define y1 cephes_y1
#define jn cephes_jn
#define jv cephes_jv
#define k0 cephes_k0
#define k0e cephes_k0e
#define k1 cephes_k1
#define k1e cephes_k1e
#define kn cephes_kn
#define nbdtrc cephes_nbdtrc
#define nbdtr cephes_nbdtr
#define nbdtri cephes_nbdtri
#define ndtr cephes_ndtr
#define erfc cephes_erfc
#define erf cephes_erf
#define ndtri cephes_ndtri
#define pdtrc cephes_pdtrc
#define pdtr cephes_pdtr
#define pdtri cephes_pdtri
#define poch cephes_poch
#define psi cephes_psi
#define rgamma cephes_rgamma
#define riemann_zeta cephes_riemann_zeta
#define round cephes_round
#define shichi cephes_shichi
#define sici cephes_sici
#define radian cephes_radian
#define sindg cephes_sindg
#define cosdg cephes_cosdg
#define sincos cephes_sincos
#define spence cephes_spence
#define stdtr cephes_stdtr
#define stdtri cephes_stdtri
#define struve_h cephes_struve_h
#define struve_l cephes_struve_l
#define struve_power_series cephes_struve_power_series
#define struve_asymp_large_z cephes_struve_asymp_large_z
#define struve_bessel_series cephes_struve_bessel_series
#define yv cephes_yv
#define tandg cephes_tandg
#define cotdg cephes_cotdg
#define log1p cephes_log1p
#define expm1 cephes_expm1
#define cosm1 cephes_cosm1
#define yn cephes_yn
#define zeta cephes_zeta
#define zetac cephes_zetac
#define smirnov cephes_smirnov
#define smirnovc cephes_smirnovc
#define smirnovi cephes_smirnovi
#define smirnovci cephes_smirnovci
#define smirnovp cephes_smirnovp
#define kolmogorov cephes_kolmogorov
#define kolmogi cephes_kolmogi
#define kolmogp cephes_kolmogp
#define kolmogc cephes_kolmogc
#define kolmogci cephes_kolmogci
#define owens_t cephes_owens_t

#endif

==> scipy_1.11.4.orig.tar.gz: scipy-1.11.4/scipy/special/cephes/cephes_names.h <==
#ifndef CEPHES_NAMES_H
#define CEPHES_NAMES_H

#define airy cephes_airy
#define bdtrc cephes_bdtrc
#define bdtr cephes_bdtr
#define bdtri cephes_bdtri
#define besselpoly cephes_besselpoly
#define beta cephes_beta
#define lbeta cephes_lbeta
#define btdtr cephes_btdtr
#define cbrt cephes_cbrt
#define chdtrc cephes_chdtrc
#define chbevl cephes_chbevl
#define chdtr cephes_chdtr
#define chdtri cephes_chdtri
#define dawsn cephes_dawsn
#define ellie cephes_ellie
#define ellik cephes_ellik
#define ellpe cephes_ellpe
#define ellpj cephes_ellpj
#define ellpk cephes_ellpk
#define exp10 cephes_exp10
#define exp2 cephes_exp2
#define expn cephes_expn
#define fdtrc cephes_fdtrc
#define fdtr cephes_fdtr
#define fdtri cephes_fdtri
#define fresnl cephes_fresnl
#define Gamma cephes_Gamma
#define lgam cephes_lgam
#define lgam_sgn cephes_lgam_sgn
#define gammasgn cephes_gammasgn
#define gdtr cephes_gdtr
#define gdtrc cephes_gdtrc
#define gdtri cephes_gdtri
#define hyp2f1 cephes_hyp2f1
#define hyperg cephes_hyperg
#define i0 cephes_i0
#define i0e cephes_i0e
#define i1 cephes_i1
#define i1e cephes_i1e
#define igamc cephes_igamc
#define igam cephes_igam
#define igami cephes_igami
#define incbet cephes_incbet
#define incbi cephes_incbi
#define iv cephes_iv
#define j0 cephes_j0
#define y0 cephes_y0
#define j1 cephes_j1
#define y1 cephes_y1
#define jn cephes_jn
#define jv cephes_jv
#define k0 cephes_k0
#define k0e cephes_k0e
#define k1 cephes_k1
#define k1e cephes_k1e
#define kn cephes_kn
#define nbdtrc cephes_nbdtrc
#define nbdtr cephes_nbdtr
#define nbdtri cephes_nbdtri
#define ndtr cephes_ndtr
#define erfc cephes_erfc
#define erf cephes_erf
#define erfinv cephes_erfinv
#define erfcinv cephes_erfcinv
#define ndtri cephes_ndtri
#define pdtrc cephes_pdtrc
#define pdtr cephes_pdtr
#define pdtri cephes_pdtri
#define poch cephes_poch
#define psi cephes_psi
#define rgamma cephes_rgamma
#define riemann_zeta cephes_riemann_zeta
#define round cephes_round
#define shichi cephes_shichi
#define sici cephes_sici
#define radian cephes_radian
#define sindg cephes_sindg
#define sinpi cephes_sinpi
#define cosdg cephes_cosdg
#define cospi cephes_cospi
#define sincos cephes_sincos
#define spence cephes_spence
#define stdtr cephes_stdtr
#define stdtri cephes_stdtri
#define struve_h cephes_struve_h
#define struve_l cephes_struve_l
#define struve_power_series cephes_struve_power_series
#define struve_asymp_large_z cephes_struve_asymp_large_z
#define struve_bessel_series cephes_struve_bessel_series
#define yv cephes_yv
#define tandg cephes_tandg
#define cotdg cephes_cotdg
#define log1p cephes_log1p
#define expm1 cephes_expm1
#define cosm1 cephes_cosm1
#define yn cephes_yn
#define zeta cephes_zeta
#define zetac cephes_zetac
#define smirnov cephes_smirnov
#define smirnovc cephes_smirnovc
#define smirnovi cephes_smirnovi
#define smirnovci cephes_smirnovci
#define smirnovp cephes_smirnovp
#define kolmogorov cephes_kolmogorov
#define kolmogi cephes_kolmogi
#define kolmogp cephes_kolmogp
#define kolmogc cephes_kolmogc
#define kolmogci cephes_kolmogci
#define owens_t cephes_owens_t

#endif
